==> 0.11.3.tar.gz: lib/src/router/hipchat/hipchat_impl.dart <==
library ac_dart.addon_routebuilder.hipchat.impl;

import 'package:atlassian_connect_shelf/src/router/hipchat/hipchat.dart';
import 'package:atlassian_connect_shelf/router.dart' hide router;
import 'package:atlassian_connect_shelf/src/descriptor_builders/hipchat.dart';
import 'package:shelf/shelf.dart';
import 'dart:async';
import 'package:atlassian_connect_host/atlassian_connect_host.dart';
import 'package:mojito/mojito.dart' hide Router, router;
import 'package:uri/uri.dart';
import 'package:atlassian_connect_shelf/src/descriptor_builders/descriptor_builder.dart';
import 'package:atlassian_connect_shelf/src/router/common/common_routes_impl.dart';

class HipchatRouterBuilderImpl
    extends CommonAddonRouterBuilderImpl<HipchatDescriptorBuilder, HipchatScope>
    implements HipchatRouterBuilder {
  HipchatRouterBuilderImpl(
      Router router,
      path,
      String addonKey,
      Uri baseUrl,
      AcHostRegistrationRepository hostRegistrationRepository,
      IsDevMode isDevMode,
      {SessionHandler sessionHandler,
      String addonSecret})
      : super(router, path, new HipchatDescriptorBuilder(addonKey, baseUrl),
            addonKey, baseUrl, hostRegistrationRepository, isDevMode,
            sessionHandler: sessionHandler, addonSecret: addonSecret);

  // TODO: consolidate with main installation handler
  void addInstallationRoute({String path: 'installed'}) {
    router.post(path, _hcInstallationHandler,
        name: DescriptorBuilder.installationRouteName);
  }

  void addRoomMessageWebhook(
      path, String name, String pattern, Function handler) {
    router.post(path, handler, name: name);
    descriptorBuilder.addWebhook('room_message', name, new RegExp(pattern));
  }

  Future<Response> _hcInstallationHandler(HcInstallationEvent installationEvent,
          AcHostService hostService) async =>
      await defaultInstallationHandler(installationEvent, hostService);

  void addOAuthProviderRoute(
      OAuthStorage oauthStore, UriTemplate completionRedirectUrl) {
    final routeNames = router.oauth.hipchat().addClient(
        (_) async => await requestContext.clientId,
        oauthStore,
        completionRedirectUrl);

    descriptorBuilder.setOAuthRouteNames(routeNames);
  }
}

==> 0.11.4.tar.gz: lib/src/router/hipchat/hipchat_impl.dart <==
library ac_dart.addon_routebuilder.hipchat.impl;

import 'package:atlassian_connect_shelf/src/router/hipchat/hipchat.dart';
import 'package:atlassian_connect_shelf/router.dart' hide router;
import 'package:atlassian_connect_shelf/src/descriptor_builders/hipchat.dart';
import 'package:shelf/shelf.dart';
import 'dart:async';
import 'package:atlassian_connect_host/atlassian_connect_host.dart';
import 'package:mojito/mojito.dart' hide Router, router;
import 'package:uri/uri.dart';
import 'package:atlassian_connect_shelf/src/descriptor_builders/descriptor_builder.dart';
import 'package:atlassian_connect_shelf/src/router/common/common_routes_impl.dart';

class HipchatRouterBuilderImpl
    extends CommonAddonRouterBuilderImpl<HipchatDescriptorBuilder, HipchatScope>
    implements HipchatRouterBuilder {
  HipchatRouterBuilderImpl(
      Router router,
      path,
      String addonKey,
      Uri baseUrl,
      AcHostRegistrationRepository hostRegistrationRepository,
      IsDevMode isDevMode,
      {SessionHandler sessionHandler,
      String addonSecret})
      : super(router, path, new HipchatDescriptorBuilder(addonKey, baseUrl),
            addonKey, baseUrl, hostRegistrationRepository, isDevMode,
            sessionHandler: sessionHandler,
            addonSecret: addonSecret,
            jwtQueryParamName: 'signed_request');

  // TODO: consolidate with main installation handler
  void addInstallationRoute({String path: 'installed'}) {
    router.post(path, _hcInstallationHandler,
        name: DescriptorBuilder.installationRouteName);
  }

  void addRoomMessageWebhook(
      path, String name, String pattern, Function handler) {
    router.post(path, handler, name: name);
    descriptorBuilder.addWebhook('room_message', name, new RegExp(pattern));
  }

  Future<Response> _hcInstallationHandler(HcInstallationEvent installationEvent,
          AcHostService hostService) async =>
      await defaultInstallationHandler(installationEvent, hostService);

  void addOAuthProviderRoute(
      OAuthStorage oauthStore, UriTemplate completionRedirectUrl) {
    final routeNames = router.oauth.hipchat().addClient(
        (_) async => await requestContext.clientId,
        oauthStore,
        completionRedirectUrl);

    descriptorBuilder.setOAuthRouteNames(routeNames);
  }

  void addSpaConfigurePage(
      {path: 'configure',
      String spaBasePath,
      String fragmentPath,
      Map<String, String> additionalUriFragment: const {}}) {
    final _spaBasePath = spaBasePath != null ? spaBasePath : 'ui';

    addSpaRedirect(path, DescriptorBuilder.configurationRouteName,
        spaBasePath: _spaBasePath,
        fragmentPath: fragmentPath,
        additionalUriFragmentParams: additionalUriFragment);
  }
}
